Schemata
========

Schemata are used to validate and store objects across backend and frontend.
They are used as document definitions for Formal which acts as a kind of ORM system.

They are also used by the frontend to generate forms and validate user input.
